Design of the Python Fast Azimuthal Integration library
=======================================================

Author: Jérôme Kieffer

Date: 18/12/2014

Keywords: Design

Target: Developers interested in using the library

Reference: API documentation

.. toctree::
   :maxdepth: 2

   ai
